package com.esignlive.guidance.sdk;

import java.text.SimpleDateFormat;
import java.util.Date;

import com.silanis.esl.sdk.DocumentPackage;
import com.silanis.esl.sdk.EslClient;
import com.silanis.esl.sdk.PackageId;
import com.silanis.esl.sdk.builder.DocumentBuilder;
import com.silanis.esl.sdk.builder.FieldBuilder;
import com.silanis.esl.sdk.builder.PackageBuilder;
import com.silanis.esl.sdk.builder.SignatureBuilder;
import com.silanis.esl.sdk.builder.SignerBuilder;

public class OptionalSignature {
	public static final String API_KEY = "your api key";
	public static final String API_URL = "https://sandbox.esignlive.com/api";
	public static final String FILE_PATH = ".../optional_signature2.pdf";

	public static void main(String[] args) {
		OptionalSignature instance = new OptionalSignature();
		
//		String packageId = instance.testOptionalBasic();
		String packageId = instance.testOptionalAndPositionExtraction();
		System.out.println(packageId);

	}

	public String testOptionalBasic() {
		EslClient eslClient = new EslClient(API_KEY, API_URL);

		String signer1Email = "signer1@mailinator.com";

		// Build the DocumentPackage object
		DocumentPackage documentPackage = PackageBuilder.newPackageNamed("Test Optional Signature " + new SimpleDateFormat("HH:mm:ss").format(new Date()))
						.withSigner(SignerBuilder.newSignerWithEmail(signer1Email)
								.withCustomId("Signer1")
								.withFirstName("Signer1.Name")
								.withLastName("Signer1.Lastname")
								.withTitle("Signer1 title")
								.withCompany("Signer1 company"))
						.withDocument(DocumentBuilder.newDocumentWithName("Sample Agreement")
								.fromFile(FILE_PATH)
								.withSignature(SignatureBuilder.signatureFor(signer1Email)
										.onPage(0)
										.atPosition(200, 150)
										.makeOptional())				//optional signature
								.withSignature(SignatureBuilder.captureFor(signer1Email)
										.atPosition(200, 250)
										.onPage(0))
								.withSignature(SignatureBuilder.initialsFor(signer1Email)
										.atPosition(200, 350)
										.onPage(0))
								)
						.build();

		// Issue the request to the e-SignLive server to create the DocumentPackage
		PackageId packageId = eslClient.createPackageOneStep(documentPackage);

		// Send the package to be signed by the participants
		eslClient.sendPackage(packageId);
		
		return packageId.getId();
	}
	
	
	public String testOptionalAndPositionExtraction() {
		EslClient eslClient = new EslClient(API_KEY, API_URL);

		String signer1Email = "signer1@mailinator.com";
		String signer2Email = "signer1@mailinator.com";

		// Build the DocumentPackage object
		DocumentPackage documentPackage = PackageBuilder.newPackageNamed("Test Optional Signature " + new SimpleDateFormat("HH:mm:ss").format(new Date()))
						.withSigner(SignerBuilder.newSignerWithEmail(signer1Email)
								.withCustomId("Signer1")
								.withFirstName("Signer1.Name")
								.withLastName("Signer1.Lastname")
								.withTitle("Signer1 title")
								.withCompany("Signer1 company"))
						.withSigner(SignerBuilder.newSignerWithEmail(signer2Email)
								.withCustomId("Signer2")
								.withFirstName("Signer2.Name")
								.withLastName("Signer2.Lastname")
								.withTitle("Signer2 title")
								.withCompany("Signer2 company"))
						.withDocument(DocumentBuilder.newDocumentWithName("Sample Agreement + Additional Service")
								.fromFile(FILE_PATH)
								.enableExtraction()
								.withSignature(SignatureBuilder.signatureFor(signer1Email)
					                     .withName("role1_signature1")
					                     .withPositionExtracted()
					                     .withField(FieldBuilder.textField()
					                    		 .withName("role1_name")
					                    		 .withPositionExtracted())
					                     .withField(FieldBuilder.textField()
					                    		 .withName("role1_age")
					                    		 .withPositionExtracted())
					                     .withField(FieldBuilder.textField()
					                    		 .withName("role1_address")
					                    		 .withPositionExtracted())
					                     .withField(FieldBuilder.textField()
					                    		 .withName("role1_city")
					                    		 .withPositionExtracted())
										 )
								.withSignature(SignatureBuilder.signatureFor(signer1Email)
										.withName("role1_signature2_optional")
										.withPositionExtracted()
										.makeOptional()							//optional signature
										)
								
								.withSignature(SignatureBuilder.signatureFor(signer2Email)
					                     .withName("role2_signature1")
					                     .withPositionExtracted()
					                     .withField(FieldBuilder.textField()
					                    		 .withName("role2_agreementNum")
					                    		 .withPositionExtracted())
					                     .withField(FieldBuilder.textArea()
					                    		 .withName("role2_comments")
					                    		 .withPositionExtracted())
										 )
								.withSignature(SignatureBuilder.signatureFor(signer2Email)
										.withName("role2_signature2_optional")
										.withPositionExtracted()
										.makeOptional()							//optional signature
										)
								)
						.build();

		// Issue the request to the e-SignLive server to create the DocumentPackage
		PackageId packageId = eslClient.createPackageOneStep(documentPackage);

		// Send the package to be signed by the participants
		eslClient.sendPackage(packageId);
		
		return packageId.getId();
	}



}
